@@ -226,6 +226,114 @@ class TestFillFixtures:
         result = testdir.runpytest()
         assert result.ret == 0
 
+    def test_override_parametrized_fixture_conftest_module(self, testdir):
+        """Test override of the parametrized fixture with non-parametrized one on the test module level."""
+        testdir.makeconftest("""
+            import pytest
+
+            @pytest.fixture(params=[1, 2, 3])
+            def spam(request):
+                return request.param
+        """)
+        testfile = testdir.makepyfile("""
+            import pytest
+
+            @pytest.fixture
+            def spam():
+                return 'spam'
+
+            def test_spam(spam):
+                assert spam == 'spam'
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines(["*1 passed*"])
+        result = testdir.runpytest(testfile)
+        result.stdout.fnmatch_lines(["*1 passed*"])
+
+    def test_override_parametrized_fixture_conftest_conftest(self, testdir):
+        """Test override of the parametrized fixture with non-parametrized one on the conftest level."""
+        testdir.makeconftest("""
+            import pytest
+
+            @pytest.fixture(params=[1, 2, 3])
+            def spam(request):
+                return request.param
+        """)
+        subdir = testdir.mkpydir('subdir')
+        subdir.join("conftest.py").write(py.code.Source("""
+            import pytest
+
+            @pytest.fixture
+            def spam():
+                return 'spam'
+        """))
+        testfile = subdir.join("test_spam.py")
+        testfile.write(py.code.Source("""
+            def test_spam(spam):
+                assert spam == "spam"
+        """))
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines(["*1 passed*"])
+        result = testdir.runpytest(testfile)
+        result.stdout.fnmatch_lines(["*1 passed*"])
+
+    def test_override_non_parametrized_fixture_conftest_module(self, testdir):
+        """Test override of the non-parametrized fixture with parametrized one on the test module level."""
+        testdir.makeconftest("""
+            import pytest
+
+            @pytest.fixture
+            def spam():
+                return 'spam'
+        """)
+        testfile = testdir.makepyfile("""
+            import pytest
+
+            @pytest.fixture(params=[1, 2, 3])
+            def spam(request):
+                return request.param
+
+            params = {'spam': 1}
+
+            def test_spam(spam):
+                assert spam == params['spam']
+                params['spam'] += 1
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines(["*3 passed*"])
+        result = testdir.runpytest(testfile)
+        result.stdout.fnmatch_lines(["*3 passed*"])
+
+    def test_override_non_parametrized_fixture_conftest_conftest(self, testdir):
+        """Test override of the non-parametrized fixture with parametrized one on the conftest level."""
+        testdir.makeconftest("""
+            import pytest
+
+            @pytest.fixture
+            def spam():
+                return 'spam'
+        """)
+        subdir = testdir.mkpydir('subdir')
+        subdir.join("conftest.py").write(py.code.Source("""
+            import pytest
+
+            @pytest.fixture(params=[1, 2, 3])
+            def spam(request):
+                return request.param
+        """))
+        testfile = subdir.join("test_spam.py")
+        testfile.write(py.code.Source("""
+            params = {'spam': 1}
+
+            def test_spam(spam):
+                assert spam == params['spam']
+                params['spam'] += 1
+        """))
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines(["*3 passed*"])
+        result = testdir.runpytest(testfile)
+        result.stdout.fnmatch_lines(["*3 passed*"])
+
     def test_autouse_fixture_plugin(self, testdir):
         # A fixture from a plugin has no baseid set, which screwed up
         # the autouse fixture handling.
@@ -261,6 +369,29 @@ class TestFillFixtures:
         ])
         assert "INTERNAL" not in result.stdout.str()
 
+    def test_fixture_excinfo_leak(self, testdir):
+        # on python2 sys.excinfo would leak into fixture executions
+        testdir.makepyfile("""
+            import sys
+            import traceback
+            import pytest
+
+            @pytest.fixture
+            def leak():
+                if sys.exc_info()[0]:  # python3 bug :)
+                    traceback.print_exc()
+                #fails
+                assert sys.exc_info() == (None, None, None)
+
+            def test_leak(leak):
+                if sys.exc_info()[0]:  # python3 bug :)
+                    traceback.print_exc()
+                assert sys.exc_info() == (None, None, None)
+        """)
+        result = testdir.runpytest()
+        assert result.ret == 0
+
+
 class TestRequestBasic:
     def test_request_attributes(self, testdir):
         item = testdir.getitem("""
@@ -477,7 +608,7 @@ class TestRequestBasic:
         reprec.assertoutcome(passed=3)
 
     def test_fixtures_sub_subdir_normalize_sep(self, testdir):
-        # this tests that normlization of nodeids takes place
+        # this tests that normalization of nodeids takes place
         b = testdir.mkdir("tests").mkdir("unit")
         b.join("conftest.py").write(py.code.Source("""
             def pytest_funcarg__arg1():
@@ -775,6 +906,27 @@ class TestFixtureUsages:
             "*1 error*"
         ])
 
+    def test_receives_funcargs_scope_mismatch_issue660(self, testdir):
+        testdir.makepyfile("""
+            import pytest
+            @pytest.fixture(scope="function")
+            def arg1():
+                return 1
+
+            @pytest.fixture(scope="module")
+            def arg2(arg1):
+                return arg1 + 1
+
+            def test_add(arg1, arg2):
+                assert arg2 == 2
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            "*ScopeMismatch*involved factories*",
+            "* def arg2*",
+            "*1 error*"
+        ])
+
     def test_funcarg_parametrized_and_used_twice(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -2300,6 +2452,35 @@ class TestShowFixtures:
             *hello world*
         """)
 
+    def test_show_fixtures_trimmed_doc(self, testdir):
+        p = testdir.makepyfile('''
+            import pytest
+            @pytest.fixture
+            def arg1():
+                """
+                line1
+                line2
+
+                """
+            @pytest.fixture
+            def arg2():
+                """
+                line1
+                line2
+
+                """
+        ''')
+        result = testdir.runpytest("--fixtures", p)
+        result.stdout.fnmatch_lines("""
+            * fixtures defined from test_show_fixtures_trimmed_doc *
+            arg2
+                line1
+                line2
+            arg1
+                line1
+                line2
+
+        """)
 
 
 class TestContextManagerFixtureFuncs:
